[open-ils-commits] [GIT] Evergreen ILS branch master updated. deb52e4c24ab9f0a87f0fe592bda968ca5e6d9ac

Evergreen Git git at git.evergreen-ils.org
Tue Jan 14 11:16:38 EST 2014


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Evergreen ILS".

The branch, master has been updated
       via  deb52e4c24ab9f0a87f0fe592bda968ca5e6d9ac (commit)
      from  48c1b5bcf4903b6705c981f5072ca8ce8537e343 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit deb52e4c24ab9f0a87f0fe592bda968ca5e6d9ac
Author: Galen Charlton <gmc at esilibrary.com>
Date:   Tue Jan 14 11:00:38 2014 -0500

    LP#1269042: prevent acq seach from building dropdown of every copy ID in the DB
    
    This patch ensures that if a user sets a search field in the
    acquisitions general search form to the line item details copy ID
    (labeled "LID - Evergreen Copy ID"), the form presents a normal
    input widget rather than trying to build a drop-down containing
    every copy ID in the database.  Except for very small databases,
    the previous behavior would mean that an open-ils.pcrud backend
    would eventually consume a great deal of memory trying to service
    a request for all copies in the system.
    
    Signed-off-by: Galen Charlton <gmc at esilibrary.com>
    Signed-off-by: Mike Rylander <mrylander at gmail.com>

diff --git a/Open-ILS/web/js/ui/default/acq/search/unified.js b/Open-ILS/web/js/ui/default/acq/search/unified.js
index 1eaad19..926662f 100644
--- a/Open-ILS/web/js/ui/default/acq/search/unified.js
+++ b/Open-ILS/web/js/ui/default/acq/search/unified.js
@@ -159,10 +159,13 @@ function TermSelectorFactory(terms) {
                 );
             } else if (term.hint == "acqlia" ||
                 (term.hint == "jub" && term.field == "eg_bib_id") ||
+                (term.hint == "acqlid" && term.field == "eg_copy_id") ||
                 (term.datatype == "link" && target == "au")) {
                 /* The test for jub.eg_bib_id is a special case to prevent
                  * AutoFieldWidget from trying to render a ridiculous dropdown
                  * of every bib record ID in the system. */
                 wStore[widgetKey] = dojo.create(
                     "input", {"type": "text"}, parentNode, "only"
                 );

-----------------------------------------------------------------------

Summary of changes:
 Open-ILS/web/js/ui/default/acq/search/unified.js |    9 ++++++---
@@ -159,10 +159,13 @@ function TermSelectorFactory(terms) {
                 (term.datatype == "link" && target == "au")) {
-                /* The test for jub.eg_bib_id is a special case to prevent
-                 * AutoFieldWidget from trying to render a ridiculous dropdown
-                 * of every bib record ID in the system. */
+                /* The tests for jub.eg_bib_id and acqlid.eg_copy_id are
+                 * special cases to prevent AutoFieldWidget from trying
+                 * to render a ridiculous dropdown of every bib or copy
+                 * record ID in the system.
+                 */
                 wStore[widgetKey] = dojo.create(
                     "input", {"type": "text"}, parentNode, "only"
 1 files changed, 6 insertions(+), 3 deletions(-)


hooks/post-receive
-- 
Evergreen ILS


More information about the open-ils-commits mailing list